import { IBaseStat } from './files';
export declare const FILE_CONTENT_STATUS: {
    PENDING: string;
    START: string;
    IN_PROGRESS: string;
    END: string;
    ERROR: string;
    RESTORE: string;
};
export interface IContentData {
    encoding: string;
    stream: IStringStream;
}
/**
 * A Stream emitting strings.
 */
export interface IStringStream {
    on(event: 'data', callback: (chunk: string) => void): void;
    on(event: 'error', callback: (err: any) => void): void;
    on(event: 'end', callback: () => void): void;
    on(event: string, callback: any): void;
}
/**
 * Content and meta information of a file.
 */
export interface IContent extends IBaseStat {
    /**
     * The content of a text file.
     */
    value: string;
    /**
     * The encoding of the content if known.
     */
    encoding: string;
    /**
     * @sri following added additionally
     */
    size?: any;
    name?: string;
    mtime?: any;
    etag?: any;
}
/**
 * Streamable content and meta information of a file.
 */
export interface IStreamContent extends IBaseStat {
    /**
     * The streamable content of a text file.
     */
    value: IStringStream;
    /**
     * The encoding of the content if known.
     */
    encoding: string;
}
