import { IResolveContentOptions, IUpdateContentOptions, IResolveFileOptions } from './options';
import { IFileStat, IResolveFileResult, IChunkOptions, IChangesChunk } from './files';
import { IContent } from './files-content';
import { IFileService } from './file-service';
import { URI } from '@vscode/monaco-editor/esm/vs/base/common/uri';
export interface IFileMicroservice extends IFileService {
    setDataSource?(ds: any): any;
    resolveFile(resource: string | URI, options?: IResolveFileOptions): Promise<IFileStat>;
    resolveFiles(toResolve: {
        resource: string | URI;
        options?: IResolveFileOptions;
    }[]): Promise<IResolveFileResult[]>;
    existsFile(resource: string | URI): Promise<boolean>;
    resolveContent(resource: string | URI, options?: IResolveContentOptions): Promise<IContent>;
    resolveStreamContent(resource: string | URI, options?: IResolveContentOptions): Promise<any>;
    updateContent(resource: string | URI, value: string, options?: IUpdateContentOptions): Promise<IFileStat>;
    updateContentChunk(resource: string, chunks: IChunkOptions[], options?: IUpdateContentOptions): Promise<IFileStat>;
    updateDelayContentByChanges(resource: string | URI, changes: IChangesChunk[], options?: IUpdateContentOptions): any;
    updateContentByChanges(resource: string | URI, changes: IChangesChunk[], options?: IUpdateContentOptions): Promise<IFileStat>;
    moveFile(source: string | URI, target: string | URI, overwrite?: boolean): Promise<IFileStat>;
    copyFile(source: string | URI, target: string | URI, overwrite?: boolean): Promise<IFileStat>;
    createFile(resource: string | URI, content?: string): Promise<IFileStat>;
    createFolder(resource: string | URI): Promise<IFileStat>;
    rename(resource: string | URI, newName: string): Promise<IFileStat>;
    del(resource: string | URI, options?: {
        useTrash?: boolean;
        recursive?: boolean;
    }): Promise<void>;
    watchFileChanges(resource: string | URI): void | Promise<void>;
    unwatchFileChanges(resource: string | URI): void | Promise<void>;
    dispose(): void | Promise<void>;
}
