import { URI } from '@vscode/monaco-editor/esm/vs/base/common/uri';
import { IEncodingOverride } from './files';
export interface IResolveFileOptions {
    resolveTo?: URI[];
    resolveSingleChildDescendants?: boolean;
}
export interface ICreateFileOptions {
    /**
     * Overwrite the file to create if it already exists on disk. Otherwise
     * an error will be thrown (FILE_MODIFIED_SINCE).
     */
    overwrite?: boolean;
}
export interface IResolveContentOptions {
    /**
     * The optional acceptTextOnly parameter allows to fail this request early if the file
     * contents are not textual.
     */
    acceptTextOnly?: boolean;
    /**
     * The optional etag parameter allows to return early from resolving the resource if
     * the contents on disk match the etag. This prevents accumulated reading of resources
     * that have been read already with the same etag.
     * It is the task of the caller to makes sure to handle this error case from the promise.
     */
    etag?: string;
    /**
     * The optional encoding parameter allows to specify the desired encoding when resolving
     * the contents of the file.
     */
    encoding?: string;
    /**
     * The optional guessEncoding parameter allows to guess encoding from content of the file.
     */
    autoGuessEncoding?: boolean;
    /**
     * Is an integer specifying where to begin reading from in the file. If position is null,
     * data will be read from the current file position.
     */
    position?: number;
}
export interface IUpdateContentOptions {
    /**
     * The encoding to use when updating a file.
     */
    encoding?: string;
    /**
     * If set to true, will enforce the selected encoding and not perform any detection using BOMs.
     */
    overwriteEncoding?: boolean;
    /**
     * Whether to overwrite a file even if it is readonly
     */
    overwriteReadonly?: boolean;
    /**
     * Wether to write to the file as elevated (admin) user. When setting this option a prompt will
     * ask the user to authenticate as super user.
     */
    writeElevated?: boolean;
    /**
     * The last known modification time of the file. This can be used to prevent dirty writes.
     */
    mtime?: number;
    /**
     * The etag of the file. This can be used to prevent dirty writes.
     */
    etag?: string;
    /**
     * Run mkdirp before saving.
     */
    mkdirp?: boolean;
}
export interface IFileServiceTestOptions {
    tmpDir?: string;
    disableWatcher?: boolean;
    encodingOverride?: IEncodingOverride[];
}
export interface IFileServiceOptions {
    tmpDir?: string;
    errorLogger?: (msg: string) => void;
    encodingOverride?: IEncodingOverride[];
    watcherIgnoredPatterns?: string[];
    disableWatcher?: boolean;
    verboseLogging?: boolean;
    useExperimentalFileWatcher?: boolean;
}
export interface FileOverwriteOptions {
    overwrite: boolean;
}
export interface FileWriteOptions {
    overwrite: boolean;
    create: boolean;
}
export interface FileDeleteOptions {
    recursive: boolean;
}
export interface IWatchOptions {
    recursive: boolean;
    excludes: string[];
}
