/**
 * States the text file editor model can be in.
 */
export declare const enum ModelState {
    SAVED = 0,
    DIRTY = 1,
    PENDING_SAVE = 2,
    /**
     * A model is in conflict mode when changes cannot be saved because the
     * underlying file has changed. Models in conflict mode are always dirty.
     */
    CONFLICT = 3,
    /**
     * A model is in orphan state when the underlying file has been deleted.
     */
    ORPHAN = 4,
    /**
     * Any error that happens during a save that is not causing the CONFLICT state.
     * Models in error mode are always diry.
     */
    ERROR = 5
}
export declare const enum StateChange {
    DIRTY = 0,
    SAVING = 1,
    SAVE_ERROR = 2,
    SAVED = 3,
    REVERTED = 4,
    ENCODING = 5,
    CONTENT_CHANGE = 6,
    ORPHANED_CHANGE = 7
}
export interface IAutoSaveConfiguration {
    autoSaveDelay: number;
    autoSaveFocusChange: boolean;
    autoSaveApplicationChange: boolean;
}
export declare const enum AutoSaveMode {
    OFF = 0,
    AFTER_SHORT_DELAY = 1,
    AFTER_LONG_DELAY = 2,
    ON_FOCUS_CHANGE = 3,
    ON_WINDOW_CHANGE = 4
}
export declare const enum SaveReason {
    EXPLICIT = 1,
    AUTO = 2,
    FOCUS_CHANGE = 3,
    WINDOW_CHANGE = 4
}
export declare const enum LoadReason {
    EDITOR = 1,
    REFERENCE = 2,
    OTHER = 3
}
export interface ISaveOptions {
    force?: boolean;
    reason?: SaveReason;
    overwriteReadonly?: boolean;
    overwriteEncoding?: boolean;
    skipSaveParticipants?: boolean;
    writeElevated?: boolean;
}
export interface ILoadOptions {
    /**
     * Go to disk bypassing any cache of the model if any.
     */
    forceReadFromDisk?: boolean;
    /**
     * Allow to load a model even if we think it is a binary file.
     */
    allowBinary?: boolean;
    /**
     * Context why the model is being loaded.
     */
    reason?: LoadReason;
}
